#!/usr/local/sbin/charm-env python3
import sys
import os.path
from charmhelpers.core import hookenv
from subprocess import check_call, CalledProcessError, STDOUT
import traceback
sys.path.append(os.path.join(os.environ['CHARM_DIR'], 'lib'))  # noqa: E402
from charms.layer.basic import activate_venv

activate_venv()


def dailycron():
    cmd = [
        '/bin/sh', '-c',
        '/usr/bin/run-one /usr/sbin/autocert --status-file /var/lib/nagios/autocert-status.txt',
        ]
    try:
        check_call(cmd, universal_newlines=True, stderr=STDOUT)
    except CalledProcessError as e:
        hookenv.action_set(dict(result=e.output))
        hookenv.action_fail('Unable to run: {}'.format(e))
    else:
        hookenv.action_set(dict(result='Run successful'))


def showstatus():
    statusfile = '/var/lib/nagios/autocert-status.txt'
    output = ''
    try:
        with open(statusfile, 'r', encoding='utf-8') as line:
            output += line
    except Exception as e:
        hookenv.action_fail('Unable to read status: {}'.format(e))
    hookenv.action_set(dict(result=output))


def main(argv):
    action = os.path.basename(argv[0])
    try:
        if action == 'dailycron':
            dailycron()
        elif action == 'showstatus':
            showstatus()
        else:
            hookenv.action_fail('Action {} not implemented'.format(action))
    except Exception:
        hookenv.action_fail('Unhandled exception')
        tb = traceback.format_exc()
        hookenv.action_set(dict(traceback=tb))
        hookenv.log('Unhandled exception in action {}'.format(action))
        print(tb)


if __name__ == '__main__':
    main(sys.argv)
