#!/usr/bin/python3

import os
import stat
import sys
import time


def nagios_critical(msg):
    """Print a message and exit with appropriate status for nagios to consider critical"""
    print(msg)
    sys.exit(2)


def check_and_open(filename, time_limit):
    check_file_freshness(filename, time_limit)
    return open(filename)


def check_file_freshness(filename, max_age_hours=48):
    max_age_seconds = max_age_hours * 60 * 60
    try:
        mtime = os.stat(filename)[stat.ST_MTIME]
    except Exception:
        nagios_critical("Couldn't stat {}".format(filename))
    else:
        seconds_since_modified = time.time() - mtime
        if seconds_since_modified > max_age_seconds:
            nagios_critical("{}: was last modified at {} and is too old".format(filename, time.ctime(mtime)))
        if seconds_since_modified < 0:
            nagios_critical("{}: was last modified on {} which is in the future.".format(filename, time.ctime(mtime)))


def check_file_contents(input_filename, time_limit):
    input_file = check_and_open(input_filename, time_limit)
    for line in input_file.readlines():
        line = line.rstrip()
        if not line:
            continue
        if not line.startswith("OK"):
            nagios_critical("Line in file not starting with 'OK': {}".format(line))


try:
    check_file_contents(sys.argv[1], 48)  # sys.argv[1] is the filename to check, 48 hours is our max age
except Exception as e:
    nagios_critical("Uncaught exception: {}".format(e))

print("All OK")
